CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
74 lines
1.4 KiB
Plaintext
74 lines
1.4 KiB
Plaintext
// RUN: %clang_cc1 -triple x86_64-pc-linux-gnu -emit-llvm -fexceptions \
|
|
// RUN: -o - -x hip %s | FileCheck %s
|
|
|
|
#include "Inputs/cuda.h"
|
|
|
|
int* hvar;
|
|
__device__ int* dvar;
|
|
|
|
// CHECK-LABEL: define {{.*}}@_Znwm
|
|
// CHECK: load ptr, ptr @hvar
|
|
void* operator new(unsigned long size) {
|
|
return hvar;
|
|
}
|
|
// CHECK-LABEL: define {{.*}}@_ZdlPv
|
|
// CHECK: store ptr inttoptr (i64 1 to ptr), ptr @hvar
|
|
void operator delete(void *p) {
|
|
hvar = (int*)1;
|
|
}
|
|
|
|
__device__ void* operator new(unsigned long size) {
|
|
return dvar;
|
|
}
|
|
|
|
__device__ void operator delete(void *p) {
|
|
dvar = (int*)11;
|
|
}
|
|
|
|
class A {
|
|
int x;
|
|
public:
|
|
A(){
|
|
x = 123;
|
|
}
|
|
};
|
|
|
|
template<class T>
|
|
class shared_ptr {
|
|
int id;
|
|
T *ptr;
|
|
public:
|
|
shared_ptr(T *p) {
|
|
id = 2;
|
|
ptr = p;
|
|
}
|
|
};
|
|
|
|
// The constructor of B calls the delete operator to clean up
|
|
// the memory allocated by the new operator when exceptions happen.
|
|
// Make sure the host delete operator is used on host side.
|
|
//
|
|
// No need to do similar checks on the device side since it does
|
|
// not support exception.
|
|
|
|
// CHECK-LABEL: define {{.*}}@main
|
|
// CHECK: call void @_ZN1BC1Ev
|
|
|
|
// CHECK-LABEL: define {{.*}}@_ZN1BC1Ev
|
|
// CHECK: call void @_ZN1BC2Ev
|
|
|
|
// CHECK-LABEL: define {{.*}}@_ZN1BC2Ev
|
|
// CHECK: call {{.*}}@_Znwm
|
|
// CHECK: invoke void @_ZN1AC1Ev
|
|
// CHECK: call void @_ZN10shared_ptrI1AEC1EPS0_
|
|
// CHECK: cleanup
|
|
// CHECK: call void @_ZdlPv
|
|
|
|
struct B{
|
|
shared_ptr<A> pa{new A};
|
|
};
|
|
|
|
int main() {
|
|
B b;
|
|
}
|